@@ -102,10 +102,8 @@ class DataForm(QtGui.QMainWindow):
         self.loop = 0
         for i, value in [(1, 5), (2, 33), (3, 60), (4, 90), (5, 100)]:
             if i == 2:
-                print str(datetime.now()) + ' self.read_data()'
                 if not self.read_data():
                     break
-                print str(datetime.now()) + ' ohi'
                 self._append_latest_traffic_status()
                 if len(self.datas) < 2:
                     self._cancel_and_show_message('Try again later', 
@@ -113,19 +111,13 @@ class DataForm(QtGui.QMainWindow):
                     "database yet. Try again after few minutes.")
                     break
             elif i == 3:
-                print str(datetime.now()) + ' self._generate_hourly()'
                 self._generate_hourly()
             elif i == 4:
-                print str(datetime.now()) + ' self._generate_daily()'
                 self._generate_daily()
             elif i == 5:
-                print str(datetime.now()) + ' self._generate_weekly()'
                 self._generate_weekly()
-                print str(datetime.now()) + ' self._generate_monthly()'
                 self._generate_monthly()
-                print str(datetime.now()) + ' self._generate_summary()'
                 self._generate_summary()
-                print str(datetime.now()) + ' ohi'
                 
             if self.progress.wasCanceled():
                 break
@@ -399,13 +391,12 @@ class TrafficRow:
         self.total_string = self.bytes_representation(self.total_bytes)
         
     def bytes_representation(self, number):
-        s = str(number)
-        if len(s) > 6:
-            s = '%s.%s MB' % (s[0:-6], s[-5])
-        elif len(s) > 3:
-            s = '%s kB' % (s[0:-3])
+        if number > 999999:
+            s = '%.1f MB' % round(number / 1000000.0, 1)
+        elif number > 999:
+            s = '%d kB' % round(number / 1000.0, 0)
         else:
-            s = '%s B' % (s)
+            s = '%d B' % (number)
         return s
         
     def add(self, other):
